@@ -18,6 +18,55 @@ import warnings
 from tencentcloud.common.abstract_model import AbstractModel
 
 
+class AutoCalloutTaskInfo(AbstractModel):
+    """自动外呼任务列表项
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Name: 任务名
+        :type Name: str
+        :param CalleeCount: 被叫数量
+        :type CalleeCount: int
+        :param Callers: 主叫号码列表
+        :type Callers: list of str
+        :param NotBefore: 起始时间戳
+        :type NotBefore: int
+        :param NotAfter: 结束时间戳
+注意：此字段可能返回 null，表示取不到有效值。
+        :type NotAfter: int
+        :param IvrId: 任务使用的IvrId
+        :type IvrId: int
+        :param State: 任务状态0初始 1运行中 2已完成 3结束中 4已结束
+        :type State: int
+        """
+        self.Name = None
+        self.CalleeCount = None
+        self.Callers = None
+        self.NotBefore = None
+        self.NotAfter = None
+        self.IvrId = None
+        self.State = None
+
+
+    def _deserialize(self, params):
+        self.Name = params.get("Name")
+        self.CalleeCount = params.get("CalleeCount")
+        self.Callers = params.get("Callers")
+        self.NotBefore = params.get("NotBefore")
+        self.NotAfter = params.get("NotAfter")
+        self.IvrId = params.get("IvrId")
+        self.State = params.get("State")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class BindStaffSkillGroupListRequest(AbstractModel):
     """BindStaffSkillGroupList请求参数结构体
 
@@ -204,6 +253,71 @@ class CallInSkillGroupMetrics(AbstractModel):
         
 
 
+class CreateCallOutSessionRequest(AbstractModel):
+    """CreateCallOutSession请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param SdkAppId: 应用 ID
+        :type SdkAppId: int
+        :param UserId: 客服用户 ID，一般为客服邮箱
+        :type UserId: str
+        :param Callee: 被叫号码，须带 0086 前缀
+        :type Callee: str
+        :param Caller: 主叫号码，须带 0086 前缀
+        :type Caller: str
+        :param IsForceUseMobile: 是否强制使用手机外呼，当前只支持 true，若为 true 请确保已配置白名单
+        :type IsForceUseMobile: bool
+        :param Uui: 自定义数据，长度限制 1024 字节
+        :type Uui: str
+        """
+        self.SdkAppId = None
+        self.UserId = None
+        self.Callee = None
+        self.Caller = None
+        self.IsForceUseMobile = None
+        self.Uui = None
+
+
+    def _deserialize(self, params):
+        self.SdkAppId = params.get("SdkAppId")
+        self.UserId = params.get("UserId")
+        self.Callee = params.get("Callee")
+        self.Caller = params.get("Caller")
+        self.IsForceUseMobile = params.get("IsForceUseMobile")
+        self.Uui = params.get("Uui")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class CreateCallOutSessionResponse(AbstractModel):
+    """CreateCallOutSession返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param SessionId: 新创建的会话 ID
+        :type SessionId: str
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.SessionId = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.SessionId = params.get("SessionId")
+        self.RequestId = params.get("RequestId")
+
+
 class CreateSDKLoginTokenRequest(AbstractModel):
     """CreateSDKLoginToken请求参数结构体
 
@@ -428,6 +542,131 @@ class DeleteStaffResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeAutoCalloutTasksRequest(AbstractModel):
+    """DescribeAutoCalloutTasks请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param SdkAppId: 呼叫中心实例Id
+        :type SdkAppId: int
+        :param PageSize: 分页大小
+        :type PageSize: int
+        :param PageNumber: 页数
+        :type PageNumber: int
+        """
+        self.SdkAppId = None
+        self.PageSize = None
+        self.PageNumber = None
+
+
+    def _deserialize(self, params):
+        self.SdkAppId = params.get("SdkAppId")
+        self.PageSize = params.get("PageSize")
+        self.PageNumber = params.get("PageNumber")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DescribeAutoCalloutTasksResponse(AbstractModel):
+    """DescribeAutoCalloutTasks返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param TotalCount: 总数
+        :type TotalCount: int
+        :param Tasks: 任务列表
+        :type Tasks: list of AutoCalloutTaskInfo
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.TotalCount = None
+        self.Tasks = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.TotalCount = params.get("TotalCount")
+        if params.get("Tasks") is not None:
+            self.Tasks = []
+            for item in params.get("Tasks"):
+                obj = AutoCalloutTaskInfo()
+                obj._deserialize(item)
+                self.Tasks.append(obj)
+        self.RequestId = params.get("RequestId")
+
+
+class DescribeCCCBuyInfoListRequest(AbstractModel):
+    """DescribeCCCBuyInfoList请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param SdkAppIds: 应用ID列表，不传时查询所有应用
+        :type SdkAppIds: list of int
+        """
+        self.SdkAppIds = None
+
+
+    def _deserialize(self, params):
+        self.SdkAppIds = params.get("SdkAppIds")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class DescribeCCCBuyInfoListResponse(AbstractModel):
+    """DescribeCCCBuyInfoList返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param TotalCount: 应用总数
+        :type TotalCount: int
+        :param SdkAppIdBuyList: 应用购买信息列表
+        :type SdkAppIdBuyList: list of SdkAppIdBuyInfo
+        :param PackageBuyList: 套餐包购买信息列表
+        :type PackageBuyList: list of PackageBuyInfo
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.TotalCount = None
+        self.SdkAppIdBuyList = None
+        self.PackageBuyList = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.TotalCount = params.get("TotalCount")
+        if params.get("SdkAppIdBuyList") is not None:
+            self.SdkAppIdBuyList = []
+            for item in params.get("SdkAppIdBuyList"):
+                obj = SdkAppIdBuyInfo()
+                obj._deserialize(item)
+                self.SdkAppIdBuyList.append(obj)
+        if params.get("PackageBuyList") is not None:
+            self.PackageBuyList = []
+            for item in params.get("PackageBuyList"):
+                obj = PackageBuyInfo()
+                obj._deserialize(item)
+                self.PackageBuyList.append(obj)
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeCallInMetricsRequest(AbstractModel):
     """DescribeCallInMetrics请求参数结构体
 
@@ -1216,7 +1455,7 @@ class ErrStaffItem(AbstractModel):
 
 
 class IMCdrInfo(AbstractModel):
-    """全媒体服务记录信息
+    """文本会话服务记录信息
 
     """
 
@@ -1227,6 +1466,14 @@ class IMCdrInfo(AbstractModel):
         :param Duration: 服务时长秒数
         :type Duration: int
         :param EndStatus: 结束状态
+0 异常结束
+1 正常结束
+3 无坐席在线
+17 坐席放弃接听
+100 黑名单
+101 坐席手动转接
+102 IVR阶段放弃
+108 用户超时自动结束
         :type EndStatus: int
         :param Nickname: 用户昵称
         :type Nickname: str
@@ -1236,6 +1483,15 @@ class IMCdrInfo(AbstractModel):
         :type StaffId: str
         :param Timestamp: 服务时间戳
         :type Timestamp: int
+        :param SessionId: 会话ID
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SessionId: str
+        :param SkillGroupId: 技能组ID
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SkillGroupId: str
+        :param SkillGroupName: 技能组名称
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SkillGroupName: str
         """
         self.Id = None
         self.Duration = None
@@ -1244,6 +1500,9 @@ class IMCdrInfo(AbstractModel):
         self.Type = None
         self.StaffId = None
         self.Timestamp = None
+        self.SessionId = None
+        self.SkillGroupId = None
+        self.SkillGroupName = None
 
 
     def _deserialize(self, params):
@@ -1254,6 +1513,9 @@ class IMCdrInfo(AbstractModel):
         self.Type = params.get("Type")
         self.StaffId = params.get("StaffId")
         self.Timestamp = params.get("Timestamp")
+        self.SessionId = params.get("SessionId")
+        self.SkillGroupId = params.get("SkillGroupId")
+        self.SkillGroupName = params.get("SkillGroupName")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1514,6 +1776,144 @@ class PSTNSessionInfo(AbstractModel):
         
 
 
+class PackageBuyInfo(AbstractModel):
+    """套餐包购买信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param PackageId: 套餐包Id
+        :type PackageId: str
+        :param Type: 套餐包类型，0-外呼套餐包|1-400呼入套餐包
+        :type Type: int
+        :param CapacitySize: 套餐包总量
+        :type CapacitySize: int
+        :param CapacityRemain: 套餐包剩余量
+        :type CapacityRemain: int
+        :param BuyTime: 购买时间戳
+        :type BuyTime: int
+        :param EndTime: 截至时间戳
+        :type EndTime: int
+        """
+        self.PackageId = None
+        self.Type = None
+        self.CapacitySize = None
+        self.CapacityRemain = None
+        self.BuyTime = None
+        self.EndTime = None
+
+
+    def _deserialize(self, params):
+        self.PackageId = params.get("PackageId")
+        self.Type = params.get("Type")
+        self.CapacitySize = params.get("CapacitySize")
+        self.CapacityRemain = params.get("CapacityRemain")
+        self.BuyTime = params.get("BuyTime")
+        self.EndTime = params.get("EndTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class PhoneNumBuyInfo(AbstractModel):
+    """号码购买信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param PhoneNum: 电话号码
+        :type PhoneNum: str
+        :param Type: 号码类型，0-固话|1-虚商号码|2-运营商号码|3-400号码
+        :type Type: int
+        :param CallType: 号码呼叫类型，1-呼入|2-呼出|3-呼入呼出
+        :type CallType: int
+        :param BuyTime: 购买时间戳
+        :type BuyTime: int
+        :param EndTime: 截至时间戳
+        :type EndTime: int
+        :param State: 号码状态，1正常|2停用
+        :type State: int
+        """
+        self.PhoneNum = None
+        self.Type = None
+        self.CallType = None
+        self.BuyTime = None
+        self.EndTime = None
+        self.State = None
+
+
+    def _deserialize(self, params):
+        self.PhoneNum = params.get("PhoneNum")
+        self.Type = params.get("Type")
+        self.CallType = params.get("CallType")
+        self.BuyTime = params.get("BuyTime")
+        self.EndTime = params.get("EndTime")
+        self.State = params.get("State")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class SdkAppIdBuyInfo(AbstractModel):
+    """应用购买信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param SdkAppId: 应用ID
+        :type SdkAppId: int
+        :param Name: 应用名称
+        :type Name: str
+        :param StaffBuyNum: 坐席购买数（还在有效期内）
+        :type StaffBuyNum: int
+        :param StaffBuyList: 坐席购买列表 （还在有效期内）
+        :type StaffBuyList: list of StaffBuyInfo
+        :param PhoneNumBuyList: 号码购买列表
+        :type PhoneNumBuyList: list of PhoneNumBuyInfo
+        """
+        self.SdkAppId = None
+        self.Name = None
+        self.StaffBuyNum = None
+        self.StaffBuyList = None
+        self.PhoneNumBuyList = None
+
+
+    def _deserialize(self, params):
+        self.SdkAppId = params.get("SdkAppId")
+        self.Name = params.get("Name")
+        self.StaffBuyNum = params.get("StaffBuyNum")
+        if params.get("StaffBuyList") is not None:
+            self.StaffBuyList = []
+            for item in params.get("StaffBuyList"):
+                obj = StaffBuyInfo()
+                obj._deserialize(item)
+                self.StaffBuyList.append(obj)
+        if params.get("PhoneNumBuyList") is not None:
+            self.PhoneNumBuyList = []
+            for item in params.get("PhoneNumBuyList"):
+                obj = PhoneNumBuyInfo()
+                obj._deserialize(item)
+                self.PhoneNumBuyList.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class SeatUserInfo(AbstractModel):
     """坐席用户信息
 
@@ -1752,6 +2152,38 @@ class SkillGroupItem(AbstractModel):
         
 
 
+class StaffBuyInfo(AbstractModel):
+    """坐席购买信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param Num: 购买坐席数量
+        :type Num: int
+        :param BuyTime: 购买时间戳
+        :type BuyTime: int
+        :param EndTime: 截至时间戳
+        :type EndTime: int
+        """
+        self.Num = None
+        self.BuyTime = None
+        self.EndTime = None
+
+
+    def _deserialize(self, params):
+        self.Num = params.get("Num")
+        self.BuyTime = params.get("BuyTime")
+        self.EndTime = params.get("EndTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class StaffInfo(AbstractModel):
     """带有技能组优先级的坐席信息
 
@@ -2027,6 +2459,12 @@ notInService       不在服务区
         :param ProtectedCallee: 被叫号码保护ID，开启号码保护映射功能时有效，且Callee字段置空
 注意：此字段可能返回 null，表示取不到有效值。
         :type ProtectedCallee: str
+        :param Uui: 客户自定义数据（User-to-User Interface）
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Uui: str
+        :param IVRKeyPressedEx: IVR按键信息（e.g. [{"Key":"1","Label":"非常满意"}]）
+注意：此字段可能返回 null，表示取不到有效值。
+        :type IVRKeyPressedEx: list of IVRKeyPressedElement
         """
         self.Caller = None
         self.Callee = None
@@ -2054,6 +2492,8 @@ notInService       不在服务区
         self.SessionId = None
         self.ProtectedCaller = None
         self.ProtectedCallee = None
+        self.Uui = None
+        self.IVRKeyPressedEx = None
 
 
     def _deserialize(self, params):
@@ -2095,6 +2535,13 @@ notInService       不在服务区
         self.SessionId = params.get("SessionId")
         self.ProtectedCaller = params.get("ProtectedCaller")
         self.ProtectedCallee = params.get("ProtectedCallee")
+        self.Uui = params.get("Uui")
+        if params.get("IVRKeyPressedEx") is not None:
+            self.IVRKeyPressedEx = []
+            for item in params.get("IVRKeyPressedEx"):
+                obj = IVRKeyPressedElement()
+                obj._deserialize(item)
+                self.IVRKeyPressedEx.append(obj)
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
