@@ -139,7 +139,7 @@ class DlcClient(AbstractClient):
 
 
     def CancelTask(self, request):
-        """取消任务执行
+        """本接口（CancelTask），用于取消任务执行
 
         :param request: Request instance for CancelTask.
         :type request: :class:`tencentcloud.dlc.v20210125.models.CancelTaskRequest`
@@ -307,7 +307,7 @@ class DlcClient(AbstractClient):
 
 
     def CreateTasks(self, request):
-        """批量创建任务
+        """本接口（CreateTasks），用于批量创建任务
 
         :param request: Request instance for CreateTasks.
         :type request: :class:`tencentcloud.dlc.v20210125.models.CreateTasksRequest`
@@ -615,7 +615,7 @@ class DlcClient(AbstractClient):
 
 
     def DescribeTable(self, request):
-        """查询单个表的详细信息。
+        """本接口（DescribeTable），用于查询单个表的详细信息。
 
         :param request: Request instance for DescribeTable.
         :type request: :class:`tencentcloud.dlc.v20210125.models.DescribeTableRequest`
@@ -643,7 +643,7 @@ class DlcClient(AbstractClient):
 
 
     def DescribeTables(self, request):
-        """本接口（DescribleTables）用于查询数据表列表。
+        """本接口（DescribeTables）用于查询数据表列表。
 
         :param request: Request instance for DescribeTables.
         :type request: :class:`tencentcloud.dlc.v20210125.models.DescribeTablesRequest`
@@ -670,6 +670,34 @@ class DlcClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeTaskResult(self, request):
+        """查询任务结果
+
+        :param request: Request instance for DescribeTaskResult.
+        :type request: :class:`tencentcloud.dlc.v20210125.models.DescribeTaskResultRequest`
+        :rtype: :class:`tencentcloud.dlc.v20210125.models.DescribeTaskResultResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeTaskResult", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeTaskResultResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeTasks(self, request):
         """该接口（DescribleTasks）用于查询任务列表
 
